has_open_document

Function has_open_document 

fn has_open_document(events: &[Event]) -> bool
Walks back through events looking for an unclosed DocumentStart (i.e. one without a matching DocumentEnd after it). Returns true if the parser is still inside a document.