struct VariantAccessImpl<'a> {
value: &'a Value,
}Fields
value: &'a ValueTrait Implementations
Sourceimpl<'de, 'a> VariantAccess<'de> for VariantAccessImpl<'a>
impl<'de, 'a> VariantAccess<'de> for VariantAccessImpl<'a>
Sourcetype Error = Error
type Error = Error
The error type that can be returned if some error occurs during
deserialization. Must match the error type of our
EnumAccess.Sourcefn unit_variant(self) -> Result<(), Error>
fn unit_variant(self) -> Result<(), Error>
Called when deserializing a variant with no values. Read more
Sourcefn newtype_variant_seed<T: DeserializeSeed<'de>>(
self,
seed: T,
) -> Result<T::Value, Error>
fn newtype_variant_seed<T: DeserializeSeed<'de>>( self, seed: T, ) -> Result<T::Value, Error>
Called when deserializing a variant with a single value. Read more
Sourcefn tuple_variant<V: Visitor<'de>>(
self,
_len: usize,
visitor: V,
) -> Result<V::Value, Error>
fn tuple_variant<V: Visitor<'de>>( self, _len: usize, visitor: V, ) -> Result<V::Value, Error>
Called when deserializing a tuple-like variant. Read more
Sourcefn struct_variant<V: Visitor<'de>>(
self,
_fields: &'static [&'static str],
visitor: V,
) -> Result<V::Value, Error>
fn struct_variant<V: Visitor<'de>>( self, _fields: &'static [&'static str], visitor: V, ) -> Result<V::Value, Error>
Called when deserializing a struct-like variant. Read more
Sourcefn newtype_variant<T>(self) -> Result<T, Self::Error>where
T: Deserialize<'de>,
fn newtype_variant<T>(self) -> Result<T, Self::Error>where
T: Deserialize<'de>,
Called when deserializing a variant with a single value. Read more